package
Version:
v0.0.0-...-a311f88
Opens a new window with list of versions in this module.
Published: Mar 24, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type UserForm struct {
Name string `json:"name"`
Gender string `json:"gender"`
Age int `json:"age"`
}
UserForm represent the user request model
Validate represent the validation method from UserForm
Source Files
¶
Click to show internal directories.
Click to hide internal directories.